@@ -188,4 +188,4 @@ def rstrip_space_in_file(file_path, line_number):
 
 def display_image(img_file):
     from IPython.display import Image
-    Image(img_file)
+    return Image(img_file)
\ No newline at end of file
